-- module_mrm.lua: Mission Replay Mini [nclok1405]

-- List cutscene-only missions?
-- true: List cutscene-only missions
-- false: Do not list cutscene-only missions
SHOW_CUTSCENES = true

-- Mission List
-- mission_name: Internal Mission ID
-- display_name: Displayed Mission Name
-- is_cutscene: Is a cutscene (skipped if SHOW_CUTSCENES = false)
-- no_warp: No warp needed (i.e. Phonecalls)
MRM_MISSIONS = {
	{ mission_name = "m01", display_name = "MISSION_NAME_M01" },
	{ mission_name = "m02", display_name = "MISSION_NAME_M02" },
	{ mission_name = "m03", display_name = "MISSION_NAME_M03" },
	{ mission_name = "m04", display_name = "MISSION_NAME_M04" },
	{ mission_name = "m05", display_name = "MISSION_NAME_M05" },
	{ mission_name = "mm_p_01", display_name = "MISSION_NAME_MM_P_01", is_cutscene = true },	-- Pierce's Guardian Angel has a unique intro
	{ mission_name = "mm_p_03", display_name = "MISSION_NAME_MM_P_03" },
	{ mission_name = "mm_p_06", display_name = "MISSION_NAME_MM_P_06", is_cutscene = true },
	{ mission_name = "sh01", display_name = "MISSION_NAME_SH01" },
	{ mission_name = "m06", display_name = "MISSION_NAME_M06" },
	{ mission_name = "m07", display_name = "MISSION_NAME_M07" },
	{ mission_name = "m08", display_name = "MISSION_NAME_M08" },
	{ mission_name = "sh02", display_name = "MISSION_NAME_SH02" },
	{ mission_name = "m09", display_name = "MISSION_NAME_M09" },
	{ mission_name = "m10", display_name = "MISSION_NAME_M10" },
	{ mission_name = "m11", display_name = "MISSION_NAME_M11" },
	{ mission_name = "m12", display_name = "MISSION_NAME_M12" },
	{ mission_name = "m13", display_name = "MISSION_NAME_M13" },
	{ mission_name = "m14", display_name = "MISSION_NAME_M14" },
	{ mission_name = "m15", display_name = "MISSION_NAME_M15" },
	{ mission_name = "sh03", display_name = "MISSION_NAME_SH03" },
	{ mission_name = "m16", display_name = "MISSION_NAME_M16" },
	{ mission_name = "mm_m16_5", display_name = "MISSION_NAME_MM_M_16_5", is_cutscene = true, no_warp = true },
	{ mission_name = "m17", display_name = "MISSION_NAME_M17" },
	{ mission_name = "m18", display_name = "MISSION_NAME_M18" },
	{ mission_name = "m19", display_name = "MISSION_NAME_M19" },
	{ mission_name = "m20", display_name = "MISSION_NAME_M20" },
	{ mission_name = "sh04", display_name = "MISSION_NAME_SH04" },
	{ mission_name = "m21", display_name = "MISSION_NAME_M21" },
	{ mission_name = "m22", display_name = "MISSION_NAME_M22" },
	{ mission_name = "m23", display_name = "MISSION_NAME_M23" },
	{ mission_name = "m24", display_name = "MISSION_NAME_M24" },
	{ mission_name = "dlc2_m01", display_name = "DLC2_M01_NAME" },
	{ mission_name = "dlc2_m02", display_name = "DLC2_M02_MISSION_NAME" },
	{ mission_name = "dlc2_m03", display_name = "DLC2_M03_MISSION_NAME" },
	{ mission_name = "dlc3_m01", display_name = "DLC3_M01_MISSION_NAME" },
	{ mission_name = "dlc3_m02", display_name = "DLC3_M02_MISSION_NAME" },
	{ mission_name = "dlc3_m03", display_name = "DLC3_M03_MISSION_NAME" },

	{ mission_name = "mm_k_01", display_name = "MISSION_NAME_MM_K_01", is_cutscene = true },
	{ mission_name = "mm_z_01", display_name = "MISSION_NAME_MM_Z_01", is_cutscene = true },
	{ mission_name = "mm_a_01", display_name = "MISSION_NAME_MM_A_01", is_cutscene = true },
	{ mission_name = "mm_k_05", display_name = "MISSION_NAME_MM_K_05", is_cutscene = true },
	{ mission_name = "mm_z_04", display_name = "MISSION_NAME_MM_Z_04", is_cutscene = true },
	{ mission_name = "mm_a_04", display_name = "MISSION_NAME_MM_A_04", is_cutscene = true },
	{ mission_name = "mm_p_07", display_name = "MISSION_NAME_MM_P_07", is_cutscene = true, no_warp = true },
	{ mission_name = "mm_k_06", display_name = "MISSION_NAME_MM_K_06", is_cutscene = true, no_warp = true },
	{ mission_name = "mm_z_05", display_name = "MISSION_NAME_MM_Z_05", is_cutscene = true, no_warp = true },
	{ mission_name = "mm_a_05", display_name = "MISSION_NAME_MM_A_05", is_cutscene = true, no_warp = true },
	{ mission_name = "dlc1_mm_01", display_name = "DLC1_MM_01", is_cutscene = true },
	{ mission_name = "dlc1_mm_06", display_name = "DLC1_MM_06", is_cutscene = true },
}

-- Previous Buttons
MRM_PREV_BUTTONS = {
	"CBA_VDC_PREV_RADIO",
	"CBA_OFC_TAUNT_TWO",
	"CBA_GAC_WEAPON_SELECT_1",
	"CBA_OFC_CROUCH",
}
-- Next Buttons
MRM_NEXT_BUTTONS = {
	"CBA_VDC_NEXT_RADIO",
	"CBA_OFC_TAUNT_THREE",
	"CBA_GAC_WEAPON_SELECT_2",
	"CBA_OFC_PICKUP_RELOAD",
}

-- List of selectable missions
Mrm_mission_table = {}

-- Marker currently active
Mrm_marker_active = false

-- Prompt currently active
Mrm_prompt_active = false

-- Help Text displayed
Mrm_help_displayed = false

-- Currently selected mission number
Mrm_selected_mission_number = 1

-- Main Thread
function mrm_main_thread()
	-- Wait until the loading screen goes away
	fade_in_block()
	
	-- Wait until the player completes the prologue
	while (not mission_is_complete("m03")) or mission_is_active() do
		thread_yield()
	end
	
	-- Setup the completed mission list
	mrm_update_mission_list()
	
	while true do
		thread_yield()
		
		-- If mission becomes active, disable everything and wait until it's over
		if mission_is_active() then
			if Mrm_marker_active then
				marker_remove("mm_p_01", SYNC_LOCAL)
				Mrm_marker_active = false
			end
			if Mrm_prompt_active then
				hud_prompt_clear(LOCAL_PLAYER)
				Mrm_prompt_active = false
			end
			
			-- Wait until the mission is no longer active
			while mission_is_active() do
				thread_yield()
			end
			
			-- Setup the completed mission list again, so when a new mission is completed it is added to the replay
			mrm_update_mission_list()
		end
		
		-- Marker
		if (not Mrm_marker_active) and mrm_is_player_close_enough(20) then
			marker_add("mm_p_01", "map_other_replaceme", OI_ASSET_USE, OI_FLAGS_FULL, SYNC_LOCAL)
			Mrm_marker_active = true
		elseif Mrm_marker_active and (not mrm_is_player_close_enough(20)) then
			marker_remove("mm_p_01", SYNC_LOCAL)
			Mrm_marker_active = false
		end
		
		-- Show Prompt
		if (not Mrm_prompt_active) and mrm_is_player_close_enough(1.8) then
			hud_prompt(LOCAL_PLAYER, Mrm_mission_table[Mrm_selected_mission_number].display_name, "mrm_triggered")
			
			-- Help message
			if not Mrm_help_displayed then
				message("PUSH {AUDIO_PLAYER_PREV_TRACK_IMG} or {AUDIO_PLAYER_NEXT_TRACK_IMG} TO SELECT MISSIONS", 5, false, SYNC_LOCAL)
				Mrm_help_displayed = true
			end
			
			-- Restore completed strongholds to Saints control.
			-- I don't know an accurate way to detect mission exit.
			-- Dying causes mission_is_active() to report false even if we retry from a checkpoint.
			if mission_is_complete("sh02") then
				mrm_stronghold_magic("safeword", true)
			end
			if mission_is_complete("sh03") then
				mrm_stronghold_magic("nuke", true)
			end
			if mission_is_complete("sh04") then
				mrm_stronghold_magic("3count", true)
			end

			Mrm_prompt_active = true
		elseif Mrm_prompt_active and (not mrm_is_player_close_enough(1.8)) then
			hud_prompt_clear(LOCAL_PLAYER)
			Mrm_prompt_active = false
		end
		
		-- Next
		if Mrm_prompt_active and mrm_is_next_button_pressed() then
			hud_prompt_clear(LOCAL_PLAYER)
			
			Mrm_selected_mission_number = Mrm_selected_mission_number + 1
			
			if Mrm_selected_mission_number > #Mrm_mission_table then
				Mrm_selected_mission_number = 1
			end
			
			hud_prompt(LOCAL_PLAYER, Mrm_mission_table[Mrm_selected_mission_number].display_name, "mrm_triggered")
		end
		
		-- Previous
		if Mrm_prompt_active and mrm_is_prev_button_pressed() then
			hud_prompt_clear(LOCAL_PLAYER)
			
			Mrm_selected_mission_number = Mrm_selected_mission_number - 1
			
			if Mrm_selected_mission_number < 1 then
				Mrm_selected_mission_number = #Mrm_mission_table
			end
			
			hud_prompt(LOCAL_PLAYER, Mrm_mission_table[Mrm_selected_mission_number].display_name, "mrm_triggered")
		end
	end
end

-- Setup the mission list
function mrm_update_mission_list()
	Mrm_mission_table = {}
	for i, mission in pairs(MRM_MISSIONS) do
		if mission_is_complete(mission.mission_name) and ((not mission.is_cutscene) or SHOW_CUTSCENES) then
			Mrm_mission_table[#Mrm_mission_table + 1] = mission
		end
	end
end

-- Next button pressed
function mrm_is_next_button_pressed()
	local next_button_pressed = false
	for i, action in pairs(MRM_NEXT_BUTTONS) do
		if player_action_just_pressed(action) then
			next_button_pressed = true
			break
		end
	end
	return next_button_pressed
end

-- Prev button pressed
function mrm_is_prev_button_pressed()
	local prev_button_pressed = false
	for i, action in pairs(MRM_PREV_BUTTONS) do
		if player_action_just_pressed(action) then
			prev_button_pressed = true
			break
		end
	end
	return prev_button_pressed
end

-- Check if the player is close enough to the trigger
function mrm_is_player_close_enough(dist)
	local px, py, pz = get_object_pos(LOCAL_PLAYER)
	local ox, oy, oz = 95.6809, 145.7421, 1049.8907
	
	local dx = px - ox
	local dy = py - oy
	local dz = pz - oz
	
	if dx < 0 then
		dx = -dx
	end
	if dy < 0 then
		dy = -dy
	end
	if dz < 0 then
		dz = -dz
	end

	if (dx < dist) and (dy < dist) and (dz < dist) then
		return true
	end
	
	return false
end

-- Trigger activated
function mrm_triggered()
	if Mrm_marker_active then
		marker_remove("mm_p_01", SYNC_LOCAL)
		Mrm_marker_active = false
	end
	if Mrm_prompt_active then
		hud_prompt_clear(LOCAL_PLAYER)
		Mrm_prompt_active = false
	end
	
	local mission_name = Mrm_mission_table[Mrm_selected_mission_number].mission_name
	local no_warp = Mrm_mission_table[Mrm_selected_mission_number].no_warp
	
	--message(mission_name, 5, false, SYNC_LOCAL)
	
	-- Change world state based on the selected mission
	if mission_name == "m02" then
		mrm_world_state_magic("m01_05")
	elseif mission_name == "m03" then
		mrm_world_state_magic("m01_05")
	elseif mission_name == "m04" then
		mrm_world_state_magic("m01_05")
	elseif mission_name == "m05" then
		mrm_world_state_magic("m01_05")
	elseif mission_name == "m06" then
		mrm_world_state_magic("m06")
	elseif mission_name == "m07" then
		mrm_world_state_magic("m07_10")
		
		-- Rescue Zimos requires Safeword stronghold
		if mission_is_complete("sh02") then
			mrm_stronghold_magic("safeword", false)
		end
	elseif mission_name == "m08" then
		mrm_world_state_magic("m07_10")
		
		-- End Cutscene needs Nuke Plant
		if mission_is_complete("sh03") then
			mrm_stronghold_magic("nuke", false)
		end
	elseif mission_name == "m09" then
		mrm_world_state_magic("m07_10")
		
		-- End Cutscene needs 3count
		if mission_is_complete("sh04") then
			mrm_stronghold_magic("3count", false)
		end
	elseif mission_name == "m10" then
		mrm_world_state_magic("m07_10")
	elseif mission_name == "m11" then
		mrm_world_state_magic("m11_13")
	elseif mission_name == "m12" then
		mrm_world_state_magic("m11_13")
	elseif mission_name == "m13" then
		mrm_world_state_magic("m11_13")
	elseif mission_name == "m14" then
		mrm_world_state_magic("m14")
	elseif mission_name == "m15" then
		mrm_world_state_magic("m15_17")
	elseif mission_name == "m16" then
		mrm_world_state_magic("m15_17")
		
		-- End Cutscene needs 3count
		if mission_is_complete("sh04") then
			mrm_stronghold_magic("3count", false)
		end
	elseif mission_name == "m17" then
		mrm_world_state_magic("m15_17")
	elseif mission_name == "m18" then
		mrm_world_state_magic("m18")
	elseif mission_name == "m19" then
		mrm_world_state_magic("m19")
	elseif mission_name == "m20" then
		mrm_world_state_magic("m20")
	elseif mission_name == "m21" then
		mrm_world_state_magic("m21_22")
	elseif mission_name == "m22" then
		mrm_world_state_magic("m21_22")
	elseif mission_name == "m23" then
		mrm_world_state_magic("m23")
	elseif mission_name == "m24" then
		mrm_world_state_magic("final")
	elseif mission_name == "sh01" then
		mrm_world_state_magic("m01_06")
	elseif mission_name == "sh02" then
		mrm_world_state_magic("sh02")
		mrm_stronghold_magic("safeword", false)
	elseif mission_name == "sh03" then
		mrm_world_state_magic("sh03")
		mrm_stronghold_magic("nuke", false)
	elseif mission_name == "sh04" then
		mrm_world_state_magic("sh04")
		mrm_stronghold_magic("3count", false)
	end
	
	-- Warp to the mission start (if we don't do this the game softlocks at the infinite loading screen)
	if not no_warp then
		sr3_teleport_mission_start(mission_name, false)
	end
	
	-- Begin the mission
	mission_set_next_mission(mission_name)
end

-- Stuff copied from Mission Replay's sr3_city.lua
function mrm_world_state_magic(mission_num)

	debug_print("Start world_state_magic")

	-- This new function completely changes world state depending on which set of missions are replayed
	
	if mission_num == "m01_05" then

		----------- BRIDGE STUFF --------------

		-- Set Traffic to Be Enabled Across Lockdown Drawbridges Again
		traffic_disable_drawbridge_area(1, false)
		traffic_disable_drawbridge_area(2, false)
		traffic_disable_drawbridge_area(3, false)
		traffic_disable_drawbridge_area(4, false)
		traffic_disable_drawbridge_area(5, false)
		traffic_disable_drawbridge_area(6, false)
		traffic_disable_drawbridge_area(7, false)
		traffic_disable_drawbridge_area(8, false)
		traffic_disable_drawbridge_area(9, false)
		traffic_disable_drawbridge_area(10, false)
		traffic_disable_drawbridge_area(11, false)
		traffic_disable_drawbridge_area(12, false)
		traffic_disable_drawbridge_area(13, false)
		traffic_disable_drawbridge_area(14, false)
		traffic_disable_drawbridge_area(15, false)
		traffic_disable_drawbridge_area(16, false)
		traffic_disable_drawbridge_area(17, false)
		traffic_disable_drawbridge_area(18, false)
		traffic_disable_drawbridge_area(19, false)
		traffic_disable_drawbridge_area(20, false)
		traffic_disable_drawbridge_area(21, false)
		traffic_disable_drawbridge_area(22, false)
		traffic_disable_drawbridge_area(23, false)
		traffic_disable_drawbridge_area(24, false)
		traffic_disable_drawbridge_area(25, false)
		traffic_disable_drawbridge_area(26, false)
		traffic_disable_drawbridge_area(27, false)
		traffic_disable_drawbridge_area(28, false)
		traffic_disable_drawbridge_area(29, false)
		traffic_disable_drawbridge_area(30, false)
		traffic_disable_drawbridge_area(31, false)
		traffic_disable_drawbridge_area(32, false)
		traffic_disable_drawbridge_area(33, false)
		traffic_disable_drawbridge_area(34, false)


		----------- m06 STUFF --------------

		-- Restore interiors for loren's building
		city_zone_swap("m6", false)
 
		--Disable Saints Tower choice
		city_zone_swap("tower_saints", false)
 
		--Disable damaged tower choice
		city_zone_swap("tower_dmg", false)
 
		-- Set Hood ('Henry Steel Mills') to NOT Spawn THE BALL from now on as ambient
		spawn_override_change_hood_alternate_spawning("HOOD_DT_01", false)


		---------- ZOMBIE STUFF -------------

		-- Set Hood ('Arapice Island') to remove Zombies
		spawn_override_change_hood_alternate_spawning("HOOD_ZOMBIE", false)

		-- Disable all the zombie zone stuff
		city_zone_swap("chemcrash", false)
		city_zone_swap("zombies", false)


		----------- STAG STUFF --------------

		-- Set Saints to be loved
		set_saints_hated(false)

		-- Set STAG Inactive
		set_stag_active(false)

		-- Disable Downtown STAG Notoriety Areas
		set_stag_notoriety_area_active(false)
 
		-- Disable STAG Lockdown
		spawn_override_change_hood_alternate_spawning("HOOD_DT_02", false)
		spawn_override_change_hood_alternate_spawning("HOOD_DT_03", false)

		-- Restore damaged Saints HQ from STAG attack
		city_zone_swap("hq_dmg", false) -- restore Saints HQ undamaged
		city_zone_swap( "hq", false ) -- revert to Morningstar colors
 
		-- Disable Stag zone stuff
		city_zone_swap("thermext1", false)
		city_zone_swap("therm2", false)
		city_zone_swap("therm3_dst", false)
		city_zone_swap("lockdown", false)
		city_zone_swap("stag", false)

		-- Statue is not blowed up
		city_zone_swap("rubble", false)

	elseif mission_num == "m06" then

		----------- BRIDGE STUFF --------------

		-- Set Traffic to Be Enabled Across Lockdown Drawbridges Again
		traffic_disable_drawbridge_area(1, false)
		traffic_disable_drawbridge_area(2, false)
		traffic_disable_drawbridge_area(3, false)
		traffic_disable_drawbridge_area(4, false)
		traffic_disable_drawbridge_area(5, false)
		traffic_disable_drawbridge_area(6, false)
		traffic_disable_drawbridge_area(7, false)
		traffic_disable_drawbridge_area(8, false)
		traffic_disable_drawbridge_area(9, false)
		traffic_disable_drawbridge_area(10, false)
		traffic_disable_drawbridge_area(11, false)
		traffic_disable_drawbridge_area(12, false)
		traffic_disable_drawbridge_area(13, false)
		traffic_disable_drawbridge_area(14, false)
		traffic_disable_drawbridge_area(15, false)
		traffic_disable_drawbridge_area(16, false)
		traffic_disable_drawbridge_area(17, false)
		traffic_disable_drawbridge_area(18, false)
		traffic_disable_drawbridge_area(19, false)
		traffic_disable_drawbridge_area(20, false)
		traffic_disable_drawbridge_area(21, false)
		traffic_disable_drawbridge_area(22, false)
		traffic_disable_drawbridge_area(23, false)
		traffic_disable_drawbridge_area(24, false)
		traffic_disable_drawbridge_area(25, false)
		traffic_disable_drawbridge_area(26, false)
		traffic_disable_drawbridge_area(27, false)
		traffic_disable_drawbridge_area(28, false)
		traffic_disable_drawbridge_area(29, false)
		traffic_disable_drawbridge_area(30, false)
		traffic_disable_drawbridge_area(31, false)
		traffic_disable_drawbridge_area(32, false)
		traffic_disable_drawbridge_area(33, false)
		traffic_disable_drawbridge_area(34, false)


		----------- m06 STUFF --------------

		-- Restore interiors for loren's building
		city_zone_swap("m6", false)
 
		--Disable Saints Tower choice
		city_zone_swap("tower_saints", false)
 
		--Disable damaged tower choice
		city_zone_swap("tower_dmg", false)
 
		-- Set Hood ('Henry Steel Mills') to NOT Spawn THE BALL from now on as ambient
		spawn_override_change_hood_alternate_spawning("HOOD_DT_01", false)


		---------- ZOMBIE STUFF -------------

		-- Set Hood ('Arapice Island') to remove Zombies
		spawn_override_change_hood_alternate_spawning("HOOD_ZOMBIE", false)

		-- Disable all the zombie zone stuff
		city_zone_swap("chemcrash", false)
		city_zone_swap("zombies", false)


		----------- STAG STUFF --------------

		-- Set Saints to be loved
		set_saints_hated(false)

		-- Set STAG Inactive
		set_stag_active(false)

		-- Disable Downtown STAG Notoriety Areas
		set_stag_notoriety_area_active(false)
 
		-- Disable STAG Lockdown
		spawn_override_change_hood_alternate_spawning("HOOD_DT_02", false)
		spawn_override_change_hood_alternate_spawning("HOOD_DT_03", false)

		-- Restore damaged Saints HQ from STAG attack
		city_zone_swap("hq_dmg", false) -- restore saints HQ undamaged
		city_zone_swap( "hq", true ) -- restore Saints HQ colors
 
		-- Disable Stag zone stuff
		city_zone_swap("thermext1", false)
		city_zone_swap("therm2", false)
		city_zone_swap("therm3_dst", false)
		city_zone_swap("lockdown", false)
		city_zone_swap("stag", false)

		-- Statue is not blowed up
		city_zone_swap("rubble", false)

	elseif mission_num == "m07_10" then

		----------- BRIDGE STUFF --------------

		-- Set Traffic to Be Enabled Across Lockdown Drawbridges Again
		traffic_disable_drawbridge_area(1, false)
		traffic_disable_drawbridge_area(2, false)
		traffic_disable_drawbridge_area(3, false)
		traffic_disable_drawbridge_area(4, false)
		traffic_disable_drawbridge_area(5, false)
		traffic_disable_drawbridge_area(6, false)
		traffic_disable_drawbridge_area(7, false)
		traffic_disable_drawbridge_area(8, false)
		traffic_disable_drawbridge_area(9, false)
		traffic_disable_drawbridge_area(10, false)
		traffic_disable_drawbridge_area(11, false)
		traffic_disable_drawbridge_area(12, false)
		traffic_disable_drawbridge_area(13, false)
		traffic_disable_drawbridge_area(14, false)
		traffic_disable_drawbridge_area(15, false)
		traffic_disable_drawbridge_area(16, false)
		traffic_disable_drawbridge_area(17, false)
		traffic_disable_drawbridge_area(18, false)
		traffic_disable_drawbridge_area(19, false)
		traffic_disable_drawbridge_area(20, false)
		traffic_disable_drawbridge_area(21, false)
		traffic_disable_drawbridge_area(22, false)
		traffic_disable_drawbridge_area(23, false)
		traffic_disable_drawbridge_area(24, false)
		traffic_disable_drawbridge_area(25, false)
		traffic_disable_drawbridge_area(26, false)
		traffic_disable_drawbridge_area(27, false)
		traffic_disable_drawbridge_area(28, false)
		traffic_disable_drawbridge_area(29, false)
		traffic_disable_drawbridge_area(30, false)
		traffic_disable_drawbridge_area(31, false)
		traffic_disable_drawbridge_area(32, false)
		traffic_disable_drawbridge_area(33, false)
		traffic_disable_drawbridge_area(34, false)


		----------- m06 STUFF --------------

		if game_choice_get_state( MISSION_06_CHOICE ) == M06_CHOICE_BRANDED_TOWER then
			city_zone_swap("tower_saints")
		else
			city_zone_swap("tower_dmg")
		end
		-- kill the building interior either way
		city_zone_swap("m6")

		-- Set Hood ('Henry Steel Mills') to Spawn THE BALL from now on as ambient
		spawn_override_change_hood_alternate_spawning("HOOD_DT_01", true)


		---------- ZOMBIE STUFF -------------

		-- Set Hood ('Arapice Island') to remove Zombies
		spawn_override_change_hood_alternate_spawning("HOOD_ZOMBIE", false)

		-- Disable all the zombie zone stuff
		city_zone_swap("chemcrash", false)
		city_zone_swap("zombies", false)


		----------- STAG STUFF --------------

		-- Set Saints to be loved
		set_saints_hated(false)

		-- Set STAG Inactive
		set_stag_active(false)

		-- Disable Downtown STAG Notoriety Areas
		set_stag_notoriety_area_active(false)
 
		-- Disable STAG Lockdown
		spawn_override_change_hood_alternate_spawning("HOOD_DT_02", false)
		spawn_override_change_hood_alternate_spawning("HOOD_DT_03", false)

		-- Restore damaged Saints HQ from STAG attack
		city_zone_swap("hq_dmg", false) -- restore saints HQ undamaged
		city_zone_swap( "hq", true ) -- restore Saints HQ colors
 
		-- Disable Stag zone stuff
		city_zone_swap("thermext1", false)
		city_zone_swap("therm2", false)
		city_zone_swap("therm3_dst", false)
		city_zone_swap("lockdown", false)
		city_zone_swap("stag", false)

		-- Statue is not blowed up
		city_zone_swap("rubble", false)

	elseif mission_num == "sh02" then --Pimp Up Hos Down Stronghold

		----------- BRIDGE STUFF --------------

		-- Set Traffic to Be Enabled Across Lockdown Drawbridges Again
		traffic_disable_drawbridge_area(1, false)
		traffic_disable_drawbridge_area(2, false)
		traffic_disable_drawbridge_area(3, false)
		traffic_disable_drawbridge_area(4, false)
		traffic_disable_drawbridge_area(5, false)
		traffic_disable_drawbridge_area(6, false)
		traffic_disable_drawbridge_area(7, false)
		traffic_disable_drawbridge_area(8, false)
		traffic_disable_drawbridge_area(9, false)
		traffic_disable_drawbridge_area(10, false)
		traffic_disable_drawbridge_area(11, false)
		traffic_disable_drawbridge_area(12, false)
		traffic_disable_drawbridge_area(13, false)
		traffic_disable_drawbridge_area(14, false)
		traffic_disable_drawbridge_area(15, false)
		traffic_disable_drawbridge_area(16, false)
		traffic_disable_drawbridge_area(17, false)
		traffic_disable_drawbridge_area(18, false)
		traffic_disable_drawbridge_area(19, false)
		traffic_disable_drawbridge_area(20, false)
		traffic_disable_drawbridge_area(21, false)
		traffic_disable_drawbridge_area(22, false)
		traffic_disable_drawbridge_area(23, false)
		traffic_disable_drawbridge_area(24, false)
		traffic_disable_drawbridge_area(25, false)
		traffic_disable_drawbridge_area(26, false)
		traffic_disable_drawbridge_area(27, false)
		traffic_disable_drawbridge_area(28, false)
		traffic_disable_drawbridge_area(29, false)
		traffic_disable_drawbridge_area(30, false)
		traffic_disable_drawbridge_area(31, false)
		traffic_disable_drawbridge_area(32, false)
		traffic_disable_drawbridge_area(33, false)
		traffic_disable_drawbridge_area(34, false)


		----------- m06 STUFF --------------

		if game_choice_get_state( MISSION_06_CHOICE ) == M06_CHOICE_BRANDED_TOWER then
			city_zone_swap("tower_saints")
		else
			city_zone_swap("tower_dmg")
		end
		-- kill the building interior either way
		city_zone_swap("m6")

		-- Set Hood ('Henry Steel Mills') to Spawn THE BALL from now on as ambient
		spawn_override_change_hood_alternate_spawning("HOOD_DT_01", true)


		---------- ZOMBIE STUFF -------------

		-- Set Hood ('Arapice Island') to remove Zombies
		spawn_override_change_hood_alternate_spawning("HOOD_ZOMBIE", false)

		-- Disable all the zombie zone stuff
		city_zone_swap("chemcrash", false)
		city_zone_swap("zombies", false)


		----------- STAG STUFF --------------

		-- Set Saints to be loved
		set_saints_hated(false)

		-- Set STAG Inactive
		set_stag_active(false)

		-- Disable Downtown STAG Notoriety Areas
		set_stag_notoriety_area_active(false)
 
		-- Disable STAG Lockdown
		spawn_override_change_hood_alternate_spawning("HOOD_DT_02", false)
		spawn_override_change_hood_alternate_spawning("HOOD_DT_03", false)

		-- Restore damaged Saints HQ from STAG attack
		city_zone_swap("hq_dmg", false) -- restore saints HQ undamaged
		city_zone_swap( "hq", true ) -- restore Saints HQ colors
 
		-- Disable Stag zone stuff
		city_zone_swap("thermext1", false)
		city_zone_swap("therm2", false)
		city_zone_swap("therm3_dst", false)
		city_zone_swap("lockdown", false)
		city_zone_swap("stag", false)

		-- Statue is not blowed up
		city_zone_swap("rubble", false)

		debug_print("world state -sh02- complete")

	elseif mission_num == "m11_13" then

		----------- BRIDGE STUFF --------------

		-- Set Traffic Status Across Lockdown Drawbridges
		traffic_disable_drawbridge_area(1, false)
		traffic_disable_drawbridge_area(2, false)
		traffic_disable_drawbridge_area(3, false)
		traffic_disable_drawbridge_area(4, false)
		traffic_disable_drawbridge_area(5, false)
		traffic_disable_drawbridge_area(6, false)
		traffic_disable_drawbridge_area(7, false)
		traffic_disable_drawbridge_area(8, false)
		traffic_disable_drawbridge_area(9, false)
		traffic_disable_drawbridge_area(10, false)
		traffic_disable_drawbridge_area(11, false)
		traffic_disable_drawbridge_area(12, false)
		traffic_disable_drawbridge_area(13, false)
		traffic_disable_drawbridge_area(14, false)
		traffic_disable_drawbridge_area(15, false)
		traffic_disable_drawbridge_area(16, false)
		traffic_disable_drawbridge_area(17, false)
		traffic_disable_drawbridge_area(18, false)
		traffic_disable_drawbridge_area(19, false)
		traffic_disable_drawbridge_area(20, false)
		traffic_disable_drawbridge_area(21, false)
		traffic_disable_drawbridge_area(22, false)
		traffic_disable_drawbridge_area(23, false)
		traffic_disable_drawbridge_area(24, false)
		traffic_disable_drawbridge_area(25, false)
		traffic_disable_drawbridge_area(26, false)
		traffic_disable_drawbridge_area(27, false)
		traffic_disable_drawbridge_area(28, false)
		traffic_disable_drawbridge_area(29, false)
		traffic_disable_drawbridge_area(30, false)
		traffic_disable_drawbridge_area(31, false)
		traffic_disable_drawbridge_area(32, false)
		traffic_disable_drawbridge_area(33, false)
		traffic_disable_drawbridge_area(34, true) -- Disables splines on road through Sunset Park that STAG cordons off


		----------- m06 STUFF --------------

		if game_choice_get_state( MISSION_06_CHOICE ) == M06_CHOICE_BRANDED_TOWER then
			city_zone_swap("tower_saints")
		else
			city_zone_swap("tower_dmg")
		end
		-- kill the building interior either way
		city_zone_swap("m6")

		-- Set Hood ('Henry Steel Mills') to Spawn THE BALL from now on as ambient
		spawn_override_change_hood_alternate_spawning("HOOD_DT_01", true)


		---------- ZOMBIE STUFF -------------

		-- Set Hood ('Arapice Island') to remove Zombies
		spawn_override_change_hood_alternate_spawning("HOOD_ZOMBIE", false)

		-- Disable all the zombie zone stuff
		city_zone_swap("chemcrash", false)
		city_zone_swap("zombies", false)


		----------- STAG STUFF --------------

		-- Set Saints to be loved
		set_saints_hated(false)

		-- Set STAG Active
		set_stag_active(true)

		-- Disable Downtown STAG Notoriety Areas
		set_stag_notoriety_area_active(false)
 
		-- Enable STAG Lockdown
		spawn_override_change_hood_alternate_spawning("HOOD_DT_02", true)

		-- Disable STAG Lockdown
		spawn_override_change_hood_alternate_spawning("HOOD_DT_03", false)

		-- Restore damaged Saints HQ from STAG attack
		city_zone_swap("hq_dmg", false) -- restore saints HQ undamaged
		city_zone_swap( "hq", true ) -- restore Saints HQ colors
 
		-- Disable Stag zone stuff
		city_zone_swap("thermext1") -- Thermopolye moves to south of DT
		city_zone_swap("therm2") -- This swap just the interior trigger and volume for thermext1.  Those two should be consolidated.
		city_zone_swap("stag") -- STAG shows up in DT
		city_zone_swap("therm3_dst", false)
		city_zone_swap("lockdown", false)

		-- Statue is not blowed up
		city_zone_swap("rubble", false)

		debug_print("world state -m11_13- complete")

	elseif mission_num == "m14" then

		----------- BRIDGE STUFF --------------

		-- Set Traffic Status Across Lockdown Drawbridges
		traffic_disable_drawbridge_area(1, false)
		traffic_disable_drawbridge_area(2, false)
		traffic_disable_drawbridge_area(3, false)
		traffic_disable_drawbridge_area(4, false)
		traffic_disable_drawbridge_area(5, false)
		traffic_disable_drawbridge_area(6, false)
		traffic_disable_drawbridge_area(7, false)
		traffic_disable_drawbridge_area(8, false)
		traffic_disable_drawbridge_area(9, false)
		traffic_disable_drawbridge_area(10, false)
		traffic_disable_drawbridge_area(11, false)
		traffic_disable_drawbridge_area(12, false)
		traffic_disable_drawbridge_area(13, false)
		traffic_disable_drawbridge_area(14, false)
		traffic_disable_drawbridge_area(15, false)
		traffic_disable_drawbridge_area(16, false)
		traffic_disable_drawbridge_area(17, false)
		traffic_disable_drawbridge_area(18, false)
		traffic_disable_drawbridge_area(19, false)
		traffic_disable_drawbridge_area(20, false)
		traffic_disable_drawbridge_area(21, false)
		traffic_disable_drawbridge_area(22, false)
		traffic_disable_drawbridge_area(23, false)
		traffic_disable_drawbridge_area(24, false)
		traffic_disable_drawbridge_area(25, false)
		traffic_disable_drawbridge_area(26, false)
		traffic_disable_drawbridge_area(27, false)
		traffic_disable_drawbridge_area(28, false)
		traffic_disable_drawbridge_area(29, false)
		traffic_disable_drawbridge_area(30, false)
		traffic_disable_drawbridge_area(31, false)
		traffic_disable_drawbridge_area(32, false)
		traffic_disable_drawbridge_area(33, false)
		traffic_disable_drawbridge_area(34, true) -- Disables splines on road through Sunset Park that STAG cordons off


		----------- m06 STUFF --------------

		if game_choice_get_state( MISSION_06_CHOICE ) == M06_CHOICE_BRANDED_TOWER then
			city_zone_swap("tower_saints")
		else
			city_zone_swap("tower_dmg")
		end
		-- kill the building interior either way
		city_zone_swap("m6")

		-- Set Hood ('Henry Steel Mills') to Spawn THE BALL from now on as ambient
		spawn_override_change_hood_alternate_spawning("HOOD_DT_01", true)


		---------- ZOMBIE STUFF -------------

		-- Set Hood ('Arapice Island') to remove Zombies
		spawn_override_change_hood_alternate_spawning("HOOD_ZOMBIE", false)

		-- Disable all the zombie zone stuff
		city_zone_swap("chemcrash", false)
		city_zone_swap("zombies", false)


		----------- STAG STUFF --------------

		-- Set Saints to be loved
		set_saints_hated(false)

		-- Set STAG Active
		set_stag_active(true)

		-- Disable Downtown STAG Notoriety Areas
		set_stag_notoriety_area_active(false)
 
		-- Enable STAG Lockdown
		spawn_override_change_hood_alternate_spawning("HOOD_DT_02", true)

		-- Disable STAG Lockdown
		spawn_override_change_hood_alternate_spawning("HOOD_DT_03", false)

		city_zone_swap("hq_dmg") -- HQ is damaged during the last mission, swap it in
		city_zone_swap( "hq", false ) -- Not sure why m13 swaps this zone in with previous morningstar colors, but added anyway just in case
 
		-- Disable Stag zone stuff
		city_zone_swap("thermext1") -- Thermopolye moves to south of DT
		city_zone_swap("therm2") -- This swap just the interior trigger and volume for thermext1.  Those two should be consolidated.
		city_zone_swap("stag") -- STAG shows up in DT
		city_zone_swap("therm3_dst", false)
		city_zone_swap("lockdown", false)

		-- Statue is not blowed up
		city_zone_swap("rubble", false)

		debug_print("world state -m14- complete")


	elseif mission_num == "m15_17" then


		----------- BRIDGE STUFF --------------

		-- Set Traffic Status Across Lockdown Drawbridges
		traffic_disable_drawbridge_area(1, false)
		traffic_disable_drawbridge_area(2, false)
		traffic_disable_drawbridge_area(3, false)
		traffic_disable_drawbridge_area(4, false)
		traffic_disable_drawbridge_area(5, false)
		traffic_disable_drawbridge_area(6, false)
		traffic_disable_drawbridge_area(7, false)
		traffic_disable_drawbridge_area(8, false)
		traffic_disable_drawbridge_area(9, false)
		traffic_disable_drawbridge_area(10, false)
		traffic_disable_drawbridge_area(11, false)
		traffic_disable_drawbridge_area(12, false)
		traffic_disable_drawbridge_area(13, false)
		traffic_disable_drawbridge_area(14, false)
		traffic_disable_drawbridge_area(15, false)
		traffic_disable_drawbridge_area(16, false)
		traffic_disable_drawbridge_area(17, false)
		traffic_disable_drawbridge_area(18, false)
		traffic_disable_drawbridge_area(19, false)
		traffic_disable_drawbridge_area(20, false)
		traffic_disable_drawbridge_area(21, false)
		traffic_disable_drawbridge_area(22, false)
		traffic_disable_drawbridge_area(23, false)
		traffic_disable_drawbridge_area(24, false)
		traffic_disable_drawbridge_area(25, false)
		traffic_disable_drawbridge_area(26, false)
		traffic_disable_drawbridge_area(27, false)
		traffic_disable_drawbridge_area(28, false)
		traffic_disable_drawbridge_area(29, false)
		traffic_disable_drawbridge_area(30, false)
		traffic_disable_drawbridge_area(31, false)
		traffic_disable_drawbridge_area(32, false)
		traffic_disable_drawbridge_area(33, false)
		traffic_disable_drawbridge_area(34, true) -- Disables splines on road through Sunset Park that STAG cordons off


		----------- m06 STUFF --------------

		if game_choice_get_state( MISSION_06_CHOICE ) == M06_CHOICE_BRANDED_TOWER then
			city_zone_swap("tower_saints")
		else
			city_zone_swap("tower_dmg")
		end
		-- kill the building interior either way
		city_zone_swap("m6")

		-- Set Hood ('Henry Steel Mills') to Spawn THE BALL from now on as ambient
		spawn_override_change_hood_alternate_spawning("HOOD_DT_01", true)


		---------- ZOMBIE STUFF -------------

		-- Set Hood ('Arapice Island') to remove Zombies
		spawn_override_change_hood_alternate_spawning("HOOD_ZOMBIE", false)

		-- Disable all the zombie zone stuff
		city_zone_swap("chemcrash", false)
		city_zone_swap("zombies", false)


		----------- STAG STUFF --------------

		-- Set Saints to be hated
		set_saints_hated(true)

		-- Set STAG Active
		set_stag_active(true)

		-- Disable Downtown STAG Notoriety Areas
		set_stag_notoriety_area_active(false)
 
		-- Enable STAG Lockdown
		spawn_override_change_hood_alternate_spawning("HOOD_DT_02", true)

		-- Disable STAG Lockdown
		spawn_override_change_hood_alternate_spawning("HOOD_DT_03", false)

		city_zone_swap("hq_dmg") -- HQ is damaged
		city_zone_swap( "hq", false ) -- Not sure why m13 swaps this zone in with previous morningstar colors, but added anyway just in case
 
		-- Disable Stag zone stuff
		city_zone_swap("thermext1") -- Thermopolye moves to south of DT
		city_zone_swap("therm2") -- This swap just the interior trigger and volume for thermext1.  Those two should be consolidated.
		city_zone_swap("stag") -- STAG shows up in DT
		city_zone_swap("therm3_dst", false)
		city_zone_swap("lockdown", false)

		-- Statue is not blowed up
		city_zone_swap("rubble", false)

	elseif mission_num == "sh03" then -- Stop All the Downloading stronghold Deckers Nuke Plant


		----------- BRIDGE STUFF --------------

		-- Set Traffic Status Across Lockdown Drawbridges
		traffic_disable_drawbridge_area(1, false)
		traffic_disable_drawbridge_area(2, false)
		traffic_disable_drawbridge_area(3, false)
		traffic_disable_drawbridge_area(4, false)
		traffic_disable_drawbridge_area(5, false)
		traffic_disable_drawbridge_area(6, false)
		traffic_disable_drawbridge_area(7, false)
		traffic_disable_drawbridge_area(8, false)
		traffic_disable_drawbridge_area(9, false)
		traffic_disable_drawbridge_area(10, false)
		traffic_disable_drawbridge_area(11, false)
		traffic_disable_drawbridge_area(12, false)
		traffic_disable_drawbridge_area(13, false)
		traffic_disable_drawbridge_area(14, false)
		traffic_disable_drawbridge_area(15, false)
		traffic_disable_drawbridge_area(16, false)
		traffic_disable_drawbridge_area(17, false)
		traffic_disable_drawbridge_area(18, false)
		traffic_disable_drawbridge_area(19, false)
		traffic_disable_drawbridge_area(20, false)
		traffic_disable_drawbridge_area(21, false)
		traffic_disable_drawbridge_area(22, false)
		traffic_disable_drawbridge_area(23, false)
		traffic_disable_drawbridge_area(24, false)
		traffic_disable_drawbridge_area(25, false)
		traffic_disable_drawbridge_area(26, false)
		traffic_disable_drawbridge_area(27, false)
		traffic_disable_drawbridge_area(28, false)
		traffic_disable_drawbridge_area(29, false)
		traffic_disable_drawbridge_area(30, false)
		traffic_disable_drawbridge_area(31, false)
		traffic_disable_drawbridge_area(32, false)
		traffic_disable_drawbridge_area(33, false)
		traffic_disable_drawbridge_area(34, true) -- Disables splines on road through Sunset Park that STAG cordons off


		----------- m06 STUFF --------------

		if game_choice_get_state( MISSION_06_CHOICE ) == M06_CHOICE_BRANDED_TOWER then
			city_zone_swap("tower_saints")
		else
			city_zone_swap("tower_dmg")
		end
		-- kill the building interior either way
		city_zone_swap("m6")

		-- Set Hood ('Henry Steel Mills') to Spawn THE BALL from now on as ambient
		spawn_override_change_hood_alternate_spawning("HOOD_DT_01", true)


		---------- ZOMBIE STUFF -------------

		-- Set Hood ('Arapice Island') to remove Zombies
		spawn_override_change_hood_alternate_spawning("HOOD_ZOMBIE", false)

		-- Disable all the zombie zone stuff
		city_zone_swap("chemcrash", false)
		city_zone_swap("zombies", false)


		----------- STAG STUFF --------------

		-- Set Saints to be hated
		set_saints_hated(true)

		-- Set STAG Active
		set_stag_active(true)

		-- Disable Downtown STAG Notoriety Areas
		set_stag_notoriety_area_active(false)
 
		-- Enable STAG Lockdown
		spawn_override_change_hood_alternate_spawning("HOOD_DT_02", true)

		-- Disable STAG Lockdown
		spawn_override_change_hood_alternate_spawning("HOOD_DT_03", false)

		city_zone_swap("hq_dmg") -- HQ is damaged
		city_zone_swap( "hq", false ) -- Not sure why m13 swaps this zone in with previous morningstar colors, but added anyway just in case
 
		-- Disable Stag zone stuff
		city_zone_swap("thermext1") -- Thermopolye moves to south of DT
		city_zone_swap("therm2") -- This swap just the interior trigger and volume for thermext1.  Those two should be consolidated.
		city_zone_swap("stag") -- STAG shows up in DT
		city_zone_swap("therm3_dst", false)
		city_zone_swap("lockdown", false)

		-- Statue is not blowed up
		city_zone_swap("rubble", false)

		debug_print("world state -sh03- complete")


	elseif mission_num == "m18" then

		----------- BRIDGE STUFF --------------

		-- Set Traffic Status Across Lockdown Drawbridges
		traffic_disable_drawbridge_area(1, true)
		traffic_disable_drawbridge_area(2, true)
		traffic_disable_drawbridge_area(3, false)
		traffic_disable_drawbridge_area(4, false)
		traffic_disable_drawbridge_area(5, false)
		traffic_disable_drawbridge_area(6, false)
		traffic_disable_drawbridge_area(7, true)
		traffic_disable_drawbridge_area(8, true)
		traffic_disable_drawbridge_area(9, true)
		traffic_disable_drawbridge_area(10, true)
		traffic_disable_drawbridge_area(11, true)
		traffic_disable_drawbridge_area(12, true)
		traffic_disable_drawbridge_area(13, true)
		traffic_disable_drawbridge_area(14, true)
		traffic_disable_drawbridge_area(15, true)
		traffic_disable_drawbridge_area(16, true)
		traffic_disable_drawbridge_area(17, true)
		traffic_disable_drawbridge_area(18, true)
		traffic_disable_drawbridge_area(19, true)
		traffic_disable_drawbridge_area(20, true)
		traffic_disable_drawbridge_area(21, true)
		traffic_disable_drawbridge_area(22, true)
		traffic_disable_drawbridge_area(23, true)
		traffic_disable_drawbridge_area(24, true)
		traffic_disable_drawbridge_area(25, true)
		traffic_disable_drawbridge_area(26, false)
		traffic_disable_drawbridge_area(27, true)
		traffic_disable_drawbridge_area(28, true)
		traffic_disable_drawbridge_area(29, true)
		traffic_disable_drawbridge_area(30, true)
		traffic_disable_drawbridge_area(31, true)
		traffic_disable_drawbridge_area(32, true)
		traffic_disable_drawbridge_area(34, true) -- Disables splines on road through Sunset Park that STAG cordons off


		----------- m06 STUFF --------------

		if game_choice_get_state( MISSION_06_CHOICE ) == M06_CHOICE_BRANDED_TOWER then
			city_zone_swap("tower_saints")
		else
			city_zone_swap("tower_dmg")
		end
		-- kill the building interior either way
		city_zone_swap("m6")

		-- Set Hood ('Henry Steel Mills') to Spawn THE BALL from now on as ambient
		spawn_override_change_hood_alternate_spawning("HOOD_DT_01", true)


		---------- ZOMBIE STUFF -------------

		-- Set Hood ('Arapice Island') to remove Zombies
		spawn_override_change_hood_alternate_spawning("HOOD_ZOMBIE", false)

		-- Disable all the zombie zone stuff
		city_zone_swap("chemcrash", false)
		city_zone_swap("zombies", false)


		----------- STAG STUFF --------------

		-- Set Saints to be hated
		set_saints_hated(true)

		-- Set STAG Active
		set_stag_active(true)

		-- Set STAG Lockdown area as immediate notoriety area
		set_stag_notoriety_area_active(true)
 
		-- Set STAG Lockdown spawning for downtown hoods to True (Hood DT_02 still missing change, waiting on Chris N. solution to having two alternate spawn groups)
		spawn_override_change_hood_alternate_spawning("HOOD_DT_02", true)
		spawn_override_change_hood_alternate_spawning("HOOD_DT_03", true)

		city_zone_swap("hq_dmg") -- HQ is damaged
		city_zone_swap( "hq", false ) -- Not sure why m13 swaps this zone in with previous morningstar colors, but added anyway just in case
 
		-- Enable Stag zone stuff
		city_zone_swap("thermext1", false)
		city_zone_swap("therm2", false) -- This swap just the interior trigger and volume for thermext1.  Those two should be consolidated.
		city_zone_swap("therm3_dst")
		city_zone_swap("lockdown")
		city_zone_swap("stag") -- STAG shows up in DT

		-- Statue is not blowed up
		city_zone_swap("rubble", false)

		debug_print("world state -m18- complete")

	elseif mission_num == "m19" then

		----------- BRIDGE STUFF --------------

		-- Set Traffic Status Across Lockdown Drawbridges
		traffic_disable_drawbridge_area(1, true)
		traffic_disable_drawbridge_area(2, true)
		traffic_disable_drawbridge_area(3, true) -- Set Drawbridge Traffic Splines to Arapice Island as 'Disabled' for zombies
		traffic_disable_drawbridge_area(4, true) -- Set Drawbridge Traffic Splines to Arapice Island as 'Disabled' for zombies
		traffic_disable_drawbridge_area(5, true) -- Set Drawbridge Traffic Splines to Arapice Island as 'Disabled' for zombies
		traffic_disable_drawbridge_area(6, true) -- Set Drawbridge Traffic Splines to Arapice Island as 'Disabled' for zombies
		traffic_disable_drawbridge_area(7, true)
		traffic_disable_drawbridge_area(8, true)
		traffic_disable_drawbridge_area(9, true)
		traffic_disable_drawbridge_area(10, true)
		traffic_disable_drawbridge_area(11, true)
		traffic_disable_drawbridge_area(12, true)
		traffic_disable_drawbridge_area(13, true)
		traffic_disable_drawbridge_area(14, true)
		traffic_disable_drawbridge_area(15, true)
		traffic_disable_drawbridge_area(16, true)
		traffic_disable_drawbridge_area(17, true)
		traffic_disable_drawbridge_area(18, true)
		traffic_disable_drawbridge_area(19, true)
		traffic_disable_drawbridge_area(20, true)
		traffic_disable_drawbridge_area(21, true)
		traffic_disable_drawbridge_area(22, true)
		traffic_disable_drawbridge_area(23, true)
		traffic_disable_drawbridge_area(24, true)
		traffic_disable_drawbridge_area(25, true)
		traffic_disable_drawbridge_area(26, true) -- Set Drawbridge Traffic Splines to Arapice Island as 'Disabled' for zombies
		traffic_disable_drawbridge_area(27, true)
		traffic_disable_drawbridge_area(28, true)
		traffic_disable_drawbridge_area(29, true)
		traffic_disable_drawbridge_area(30, true)
		traffic_disable_drawbridge_area(31, true)
		traffic_disable_drawbridge_area(32, true)
		traffic_disable_drawbridge_area(34, true) -- Disables splines on road through Sunset Park that STAG cordons off


		----------- m06 STUFF --------------

		if game_choice_get_state( MISSION_06_CHOICE ) == M06_CHOICE_BRANDED_TOWER then
			city_zone_swap("tower_saints")
		else
			city_zone_swap("tower_dmg")
		end
		-- kill the building interior either way
		city_zone_swap("m6")

		-- Set Hood ('Henry Steel Mills') to Spawn THE BALL from now on as ambient
		spawn_override_change_hood_alternate_spawning("HOOD_DT_01", true)


		----------- STAG STUFF --------------

		-- Set Saints to be hated
		set_saints_hated(true)

		-- Set STAG Active
		set_stag_active(true)

		-- Set STAG Lockdown area as immediate notoriety area
		set_stag_notoriety_area_active(true)
 
		-- Set STAG Lockdown spawning for downtown hoods to True (Hood DT_02 still missing change, waiting on Chris N. solution to having two alternate spawn groups)
		spawn_override_change_hood_alternate_spawning("HOOD_DT_02", true)
		spawn_override_change_hood_alternate_spawning("HOOD_DT_03", true)

		city_zone_swap("hq_dmg") -- HQ is damaged
		city_zone_swap( "hq", false ) -- Not sure why m13 swaps this zone in with previous morningstar colors, but added anyway just in case
 
		-- Enable Stag zone stuff
		city_zone_swap("thermext1", false)
		city_zone_swap("therm2", false) -- This swap just the interior trigger and volume for thermext1.  Those two should be consolidated.
		city_zone_swap("therm3_dst")
		city_zone_swap("lockdown")
		city_zone_swap("stag") -- STAG shows up in DT

		-- Statue is not blowed up
		city_zone_swap("rubble", false)


		---------- ZOMBIE STUFF -------------

		-- Set Hood ('Arapice Island') to Spawn Zombies from now on as ambient
		spawn_override_change_hood_alternate_spawning("HOOD_ZOMBIE", true)

		-- Swap the Zombie zone
		city_zone_swap("chemcrash")
		city_zone_swap("zombies")

		debug_print("world state -m19- complete")


	elseif mission_num == "sh04" then -- 3 Count Beatdown Stronghold

		----------- BRIDGE STUFF --------------

		-- Set Traffic Status Across Lockdown Drawbridges
		traffic_disable_drawbridge_area(1, true)
		traffic_disable_drawbridge_area(2, true)
		traffic_disable_drawbridge_area(3, true) -- Set Drawbridge Traffic Splines to Arapice Island as 'Disabled' for zombies
		traffic_disable_drawbridge_area(4, true) -- Set Drawbridge Traffic Splines to Arapice Island as 'Disabled' for zombies
		traffic_disable_drawbridge_area(5, true) -- Set Drawbridge Traffic Splines to Arapice Island as 'Disabled' for zombies
		traffic_disable_drawbridge_area(6, true) -- Set Drawbridge Traffic Splines to Arapice Island as 'Disabled' for zombies
		traffic_disable_drawbridge_area(7, true)
		traffic_disable_drawbridge_area(8, true)
		traffic_disable_drawbridge_area(9, true)
		traffic_disable_drawbridge_area(10, true)
		traffic_disable_drawbridge_area(11, true)
		traffic_disable_drawbridge_area(12, true)
		traffic_disable_drawbridge_area(13, true)
		traffic_disable_drawbridge_area(14, true)
		traffic_disable_drawbridge_area(15, true)
		traffic_disable_drawbridge_area(16, true)
		traffic_disable_drawbridge_area(17, true)
		traffic_disable_drawbridge_area(18, true)
		traffic_disable_drawbridge_area(19, true)
		traffic_disable_drawbridge_area(20, true)
		traffic_disable_drawbridge_area(21, true)
		traffic_disable_drawbridge_area(22, true)
		traffic_disable_drawbridge_area(23, true)
		traffic_disable_drawbridge_area(24, true)
		traffic_disable_drawbridge_area(25, true)
		traffic_disable_drawbridge_area(26, true) -- Set Drawbridge Traffic Splines to Arapice Island as 'Disabled' for zombies
		traffic_disable_drawbridge_area(27, true)
		traffic_disable_drawbridge_area(28, true)
		traffic_disable_drawbridge_area(29, true)
		traffic_disable_drawbridge_area(30, true)
		traffic_disable_drawbridge_area(31, true)
		traffic_disable_drawbridge_area(32, true)
		traffic_disable_drawbridge_area(34, true) -- Disables splines on road through Sunset Park that STAG cordons off


		----------- m06 STUFF --------------

		if game_choice_get_state( MISSION_06_CHOICE ) == M06_CHOICE_BRANDED_TOWER then
			city_zone_swap("tower_saints")
		else
			city_zone_swap("tower_dmg")
		end
		-- kill the building interior either way
		city_zone_swap("m6")

		-- Set Hood ('Henry Steel Mills') to Spawn THE BALL from now on as ambient
		spawn_override_change_hood_alternate_spawning("HOOD_DT_01", true)


		----------- STAG STUFF --------------

		-- Set Saints to be hated
		set_saints_hated(true)

		-- Set STAG Active
		set_stag_active(true)

		-- Set STAG Lockdown area as immediate notoriety area
		set_stag_notoriety_area_active(true)
 
		-- Set STAG Lockdown spawning for downtown hoods to True (Hood DT_02 still missing change, waiting on Chris N. solution to having two alternate spawn groups)
		spawn_override_change_hood_alternate_spawning("HOOD_DT_02", true)
		spawn_override_change_hood_alternate_spawning("HOOD_DT_03", true)

		city_zone_swap("hq_dmg") -- HQ is damaged
		city_zone_swap( "hq", false ) -- Not sure why m13 swaps this zone in with previous morningstar colors, but added anyway just in case
 
		-- Enable Stag zone stuff
		city_zone_swap("thermext1", false)
		city_zone_swap("therm2", false) -- This swap just the interior trigger and volume for thermext1.  Those two should be consolidated.
		city_zone_swap("therm3_dst")
		city_zone_swap("lockdown")
		city_zone_swap("stag") -- STAG shows up in DT

		-- Statue is not blowed up
		city_zone_swap("rubble", false)


		---------- ZOMBIE STUFF -------------

		-- Set Hood ('Arapice Island') to Spawn Zombies from now on as ambient
		spawn_override_change_hood_alternate_spawning("HOOD_ZOMBIE", true)

		-- Swap the Zombie zone
		city_zone_swap("chemcrash")
		city_zone_swap("zombies")

		debug_print("world state -sh04- complete")


	elseif mission_num == "m20" then

		----------- BRIDGE STUFF --------------

		-- Set Traffic Status Across Lockdown Drawbridges
		traffic_disable_drawbridge_area(1, true)
		traffic_disable_drawbridge_area(2, true)
		traffic_disable_drawbridge_area(3, true) -- Set Drawbridge Traffic Splines to Arapice Island as 'Disabled' for zombies
		traffic_disable_drawbridge_area(4, true) -- Set Drawbridge Traffic Splines to Arapice Island as 'Disabled' for zombies
		traffic_disable_drawbridge_area(5, true) -- Set Drawbridge Traffic Splines to Arapice Island as 'Disabled' for zombies
		traffic_disable_drawbridge_area(6, true) -- Set Drawbridge Traffic Splines to Arapice Island as 'Disabled' for zombies
		traffic_disable_drawbridge_area(7, true)
		traffic_disable_drawbridge_area(8, true)
		traffic_disable_drawbridge_area(9, true)
		traffic_disable_drawbridge_area(10, true)
		traffic_disable_drawbridge_area(11, true)
		traffic_disable_drawbridge_area(12, true)
		traffic_disable_drawbridge_area(13, true)
		traffic_disable_drawbridge_area(14, true)
		traffic_disable_drawbridge_area(15, true)
		traffic_disable_drawbridge_area(16, true)
		traffic_disable_drawbridge_area(17, true)
		traffic_disable_drawbridge_area(18, true)
		traffic_disable_drawbridge_area(19, true)
		traffic_disable_drawbridge_area(20, true)
		traffic_disable_drawbridge_area(21, true)
		traffic_disable_drawbridge_area(22, true)
		traffic_disable_drawbridge_area(23, true)
		traffic_disable_drawbridge_area(24, true)
		traffic_disable_drawbridge_area(25, true)
		traffic_disable_drawbridge_area(26, true) -- Set Drawbridge Traffic Splines to Arapice Island as 'Disabled' for zombies
		traffic_disable_drawbridge_area(27, true)
		traffic_disable_drawbridge_area(28, true)
		traffic_disable_drawbridge_area(29, true)
		traffic_disable_drawbridge_area(30, true)
		traffic_disable_drawbridge_area(31, true)
		traffic_disable_drawbridge_area(32, true)
		traffic_disable_drawbridge_area(34, true) -- Disables splines on road through Sunset Park that STAG cordons off


		----------- m06 STUFF --------------

		if game_choice_get_state( MISSION_06_CHOICE ) == M06_CHOICE_BRANDED_TOWER then
			city_zone_swap("tower_saints")
		else
			city_zone_swap("tower_dmg")
		end
		-- kill the building interior either way
		city_zone_swap("m6")

		-- Set Hood ('Henry Steel Mills') to Spawn THE BALL from now on as ambient
		spawn_override_change_hood_alternate_spawning("HOOD_DT_01", true)


		----------- STAG STUFF --------------

		-- Set Saints to be hated
		set_saints_hated(true)

		-- Set STAG Active
		set_stag_active(true)

		-- Set STAG Lockdown area as immediate notoriety area
		set_stag_notoriety_area_active(true)
 
		-- Set STAG Lockdown spawning for downtown hoods to True (Hood DT_02 still missing change, waiting on Chris N. solution to having two alternate spawn groups)
		spawn_override_change_hood_alternate_spawning("HOOD_DT_02", true)
		spawn_override_change_hood_alternate_spawning("HOOD_DT_03", true)

		city_zone_swap("hq_dmg") -- HQ is damaged
		city_zone_swap( "hq", false ) -- Not sure why m13 swaps this zone in with previous morningstar colors, but added anyway just in case
 
		-- Enable Stag zone stuff
		city_zone_swap("thermext1", false)
		city_zone_swap("therm2", false) -- This swap just the interior trigger and volume for thermext1.  Those two should be consolidated.
		city_zone_swap("therm3_dst")
		city_zone_swap("lockdown")
		city_zone_swap("stag") -- STAG shows up in DT

		if game_choice_get_state( MISSION_22_CHOICE ) == M22_CHOICE_KILLBANE_KILL then
			city_zone_swap("rubble") -- Player went for Killbane, statue got blowed up
		else
			city_zone_swap("rubble", false) -- Statue saved
		end


		---------- ZOMBIE STUFF -------------

		-- Set Hood ('Arapice Island') to Spawn Zombies from now on as ambient
		spawn_override_change_hood_alternate_spawning("HOOD_ZOMBIE", true)

		-- Swap the Zombie zone
		city_zone_swap("chemcrash")
		city_zone_swap("zombies")

		debug_print("world state -m20- complete")


	elseif mission_num == "m21_22" then

		----------- BRIDGE STUFF --------------

		-- Set Traffic Status Across Lockdown Drawbridges
		traffic_disable_drawbridge_area(1, true)
		traffic_disable_drawbridge_area(2, true)
		traffic_disable_drawbridge_area(3, true) -- Set Drawbridge Traffic Splines to Arapice Island as 'Disabled' for zombies
		traffic_disable_drawbridge_area(4, true) -- Set Drawbridge Traffic Splines to Arapice Island as 'Disabled' for zombies
		traffic_disable_drawbridge_area(5, true) -- Set Drawbridge Traffic Splines to Arapice Island as 'Disabled' for zombies
		traffic_disable_drawbridge_area(6, true) -- Set Drawbridge Traffic Splines to Arapice Island as 'Disabled' for zombies
		traffic_disable_drawbridge_area(7, true)
		traffic_disable_drawbridge_area(8, true)
		traffic_disable_drawbridge_area(9, true)
		traffic_disable_drawbridge_area(10, true)
		traffic_disable_drawbridge_area(11, true)
		traffic_disable_drawbridge_area(12, true)
		traffic_disable_drawbridge_area(13, true)
		traffic_disable_drawbridge_area(14, true)
		traffic_disable_drawbridge_area(15, true)
		traffic_disable_drawbridge_area(16, true)
		traffic_disable_drawbridge_area(17, true)
		traffic_disable_drawbridge_area(18, true)
		traffic_disable_drawbridge_area(19, true)
		traffic_disable_drawbridge_area(20, true)
		traffic_disable_drawbridge_area(21, true)
		traffic_disable_drawbridge_area(22, true)
		traffic_disable_drawbridge_area(23, true)
		traffic_disable_drawbridge_area(24, true)
		traffic_disable_drawbridge_area(25, true)
		traffic_disable_drawbridge_area(26, true) -- Set Drawbridge Traffic Splines to Arapice Island as 'Disabled' for zombies
		traffic_disable_drawbridge_area(27, true)
		traffic_disable_drawbridge_area(28, true)
		traffic_disable_drawbridge_area(29, true)
		traffic_disable_drawbridge_area(30, true)
		traffic_disable_drawbridge_area(31, true)
		traffic_disable_drawbridge_area(32, true)
		traffic_disable_drawbridge_area(34, true) -- Disables splines on road through Sunset Park that STAG cordons off


		----------- m06 STUFF --------------

		if game_choice_get_state( MISSION_06_CHOICE ) == M06_CHOICE_BRANDED_TOWER then
			city_zone_swap("tower_saints")
		else
			city_zone_swap("tower_dmg")
		end
		-- kill the building interior either way
		city_zone_swap("m6")

		-- Set Hood ('Henry Steel Mills') to Spawn THE BALL from now on as ambient
		spawn_override_change_hood_alternate_spawning("HOOD_DT_01", true)


		----------- STAG STUFF --------------

		-- Set Saints to be hated
		set_saints_hated(true)

		-- Set STAG Active
		set_stag_active(true)

		-- Set STAG Lockdown area as immediate notoriety area
		set_stag_notoriety_area_active(true)
 
		-- Set STAG Lockdown spawning for downtown hoods to True (Hood DT_02 still missing change, waiting on Chris N. solution to having two alternate spawn groups)
		spawn_override_change_hood_alternate_spawning("HOOD_DT_02", true)
		spawn_override_change_hood_alternate_spawning("HOOD_DT_03", true)

		city_zone_swap("hq_dmg") -- HQ is damaged
		city_zone_swap( "hq", false ) -- Not sure why m13 swaps this zone in with previous morningstar colors, but added anyway just in case
 
		-- Enable Stag zone stuff
		city_zone_swap("thermext1", false)
		city_zone_swap("therm2", false) -- This swap just the interior trigger and volume for thermext1.  Those two should be consolidated.
		city_zone_swap("therm3_dst")
		city_zone_swap("lockdown")
		city_zone_swap("stag") -- STAG shows up in DT

		if game_choice_get_state( MISSION_22_CHOICE ) == M22_CHOICE_KILLBANE_KILL then
			city_zone_swap("rubble") -- Player went for Killbane, statue got blowed up
		else
			city_zone_swap("rubble", false) -- Statue saved
		end


		---------- ZOMBIE STUFF -------------

		-- Set Hood ('Arapice Island') to Spawn Zombies from now on as ambient
		spawn_override_change_hood_alternate_spawning("HOOD_ZOMBIE", true)

		-- Swap the Zombie zone
		city_zone_swap("chemcrash")
		city_zone_swap("zombies")

		debug_print("world state -m21_22- complete")


	elseif mission_num == "m23" then

		----------- BRIDGE STUFF --------------

		-- Set Traffic Status Across Lockdown Drawbridges
		traffic_disable_drawbridge_area(1, true)
		traffic_disable_drawbridge_area(2, true)
		traffic_disable_drawbridge_area(3, true) -- Set Drawbridge Traffic Splines to Arapice Island as 'Disabled' for zombies
		traffic_disable_drawbridge_area(4, true) -- Set Drawbridge Traffic Splines to Arapice Island as 'Disabled' for zombies
		traffic_disable_drawbridge_area(5, true) -- Set Drawbridge Traffic Splines to Arapice Island as 'Disabled' for zombies
		traffic_disable_drawbridge_area(6, true) -- Set Drawbridge Traffic Splines to Arapice Island as 'Disabled' for zombies
		traffic_disable_drawbridge_area(7, false)
		traffic_disable_drawbridge_area(8, false)
		traffic_disable_drawbridge_area(9, false)
		traffic_disable_drawbridge_area(10, false)
		traffic_disable_drawbridge_area(11, false)
		traffic_disable_drawbridge_area(12, false)
		traffic_disable_drawbridge_area(13, false)
		traffic_disable_drawbridge_area(14, false)
		traffic_disable_drawbridge_area(15, false)
		traffic_disable_drawbridge_area(16, false)
		traffic_disable_drawbridge_area(17, false)
		traffic_disable_drawbridge_area(18, false)
		traffic_disable_drawbridge_area(19, false)
		traffic_disable_drawbridge_area(20, false)
		traffic_disable_drawbridge_area(21, false)
		traffic_disable_drawbridge_area(22, false)
		traffic_disable_drawbridge_area(23, false)
		traffic_disable_drawbridge_area(24, false)
		traffic_disable_drawbridge_area(25, false)
		traffic_disable_drawbridge_area(26, true) -- Set Drawbridge Traffic Splines to Arapice Island as 'Disabled' for zombies
		traffic_disable_drawbridge_area(27, false)
		traffic_disable_drawbridge_area(28, false)
		traffic_disable_drawbridge_area(29, false)
		traffic_disable_drawbridge_area(30, false)
		traffic_disable_drawbridge_area(31, false)
		traffic_disable_drawbridge_area(32, false)
		traffic_disable_drawbridge_area(33, false)
		traffic_disable_drawbridge_area(34, false)


		----------- m06 STUFF --------------

		if game_choice_get_state( MISSION_06_CHOICE ) == M06_CHOICE_BRANDED_TOWER then
			city_zone_swap("tower_saints")
		else
			city_zone_swap("tower_dmg")
		end
		-- kill the building interior either way
		city_zone_swap("m6")

		-- Set Hood ('Henry Steel Mills') to Spawn THE BALL from now on as ambient
		spawn_override_change_hood_alternate_spawning("HOOD_DT_01", true)


		----------- STAG STUFF --------------

		-- Set Saints to be loved again
		set_saints_hated(false)

		-- Set STAG Inactive
		set_stag_active(false)

		-- Disable Downtown Notoriety Areas
		set_stag_notoriety_area_active(false)
 
		-- Remove Lockdown Spawning from Downtown Hoods
		spawn_override_change_hood_alternate_spawning("HOOD_DT_02", false)
		spawn_override_change_hood_alternate_spawning("HOOD_DT_03", false)

		city_zone_swap("hq_dmg", DISABLE) -- restore saints HQ
		city_zone_swap( "hq", true ) -- restore Saints color schemes
 
		-- Enable Stag zone stuff
		city_zone_swap("thermext1", false)
		city_zone_swap("therm2", false) -- This swap just the interior trigger and volume for thermext1.  Those two should be consolidated.
		city_zone_swap("therm3_dst")
		city_zone_swap("lockdown")
		city_zone_swap("stag") -- STAG shows up in DT

		if game_choice_get_state( MISSION_22_CHOICE ) == M22_CHOICE_KILLBANE_KILL then
			city_zone_swap("rubble") -- Player went for Killbane, statue got blowed up
		else
			city_zone_swap("rubble", false) -- Statue saved
		end


		---------- ZOMBIE STUFF -------------

		-- Set Hood ('Arapice Island') to Spawn Zombies from now on as ambient
		spawn_override_change_hood_alternate_spawning("HOOD_ZOMBIE", true)

		-- Swap the Zombie zone
		city_zone_swap("chemcrash")
		city_zone_swap("zombies")

		debug_print("world state -m23- complete")


	elseif mission_num == "final" then

		----------- BRIDGE STUFF --------------

		-- Set Traffic Status Across Lockdown Drawbridges
		traffic_disable_drawbridge_area(1, true)
		traffic_disable_drawbridge_area(2, true)
		traffic_disable_drawbridge_area(3, true) -- Set Drawbridge Traffic Splines to Arapice Island as 'Disabled' for zombies
		traffic_disable_drawbridge_area(4, true) -- Set Drawbridge Traffic Splines to Arapice Island as 'Disabled' for zombies
		traffic_disable_drawbridge_area(5, true) -- Set Drawbridge Traffic Splines to Arapice Island as 'Disabled' for zombies
		traffic_disable_drawbridge_area(6, true) -- Set Drawbridge Traffic Splines to Arapice Island as 'Disabled' for zombies
		traffic_disable_drawbridge_area(7, false)
		traffic_disable_drawbridge_area(8, false)
		traffic_disable_drawbridge_area(9, false)
		traffic_disable_drawbridge_area(10, false)
		traffic_disable_drawbridge_area(11, false)
		traffic_disable_drawbridge_area(12, false)
		traffic_disable_drawbridge_area(13, false)
		traffic_disable_drawbridge_area(14, false)
		traffic_disable_drawbridge_area(15, false)
		traffic_disable_drawbridge_area(16, false)
		traffic_disable_drawbridge_area(17, false)
		traffic_disable_drawbridge_area(18, false)
		traffic_disable_drawbridge_area(19, false)
		traffic_disable_drawbridge_area(20, false)
		traffic_disable_drawbridge_area(21, false)
		traffic_disable_drawbridge_area(22, false)
		traffic_disable_drawbridge_area(23, false)
		traffic_disable_drawbridge_area(24, false)
		traffic_disable_drawbridge_area(25, false)
		traffic_disable_drawbridge_area(26, true) -- Set Drawbridge Traffic Splines to Arapice Island as 'Disabled' for zombies
		traffic_disable_drawbridge_area(27, false)
		traffic_disable_drawbridge_area(28, false)
		traffic_disable_drawbridge_area(29, false)
		traffic_disable_drawbridge_area(30, false)
		traffic_disable_drawbridge_area(31, false)
		traffic_disable_drawbridge_area(32, false)
		traffic_disable_drawbridge_area(33, false)
		traffic_disable_drawbridge_area(34, false)

		----------- m06 STUFF --------------

		if game_choice_get_state( MISSION_06_CHOICE ) == M06_CHOICE_BRANDED_TOWER then
			city_zone_swap("tower_saints")
		else
			city_zone_swap("tower_dmg")
		end
		-- kill the building interior either way
		city_zone_swap("m6")

		-- Set Hood ('Henry Steel Mills') to Spawn THE BALL from now on as ambient
		spawn_override_change_hood_alternate_spawning("HOOD_DT_01", true)


		----------- STAG STUFF --------------

		-- Set Saints to be loved again
		set_saints_hated(false)

		-- Set STAG Inactive
		set_stag_active(false)

		-- Disable Downtown Notoriety Areas
		set_stag_notoriety_area_active(false)
 
		-- Remove Lockdown Spawning from Downtown Hoods
		spawn_override_change_hood_alternate_spawning("HOOD_DT_02", false)
		spawn_override_change_hood_alternate_spawning("HOOD_DT_03", false)

		city_zone_swap("hq_dmg", DISABLE) -- restore saints HQ
		city_zone_swap( "hq", true ) -- restore saints color scheme
 
		-- Enable Stag zone stuff
		city_zone_swap("thermext1", false)
		city_zone_swap("therm2", false) -- This swap just the interior trigger and volume for thermext1.  Those two should be consolidated.
		city_zone_swap("therm3_dst")
		city_zone_swap("lockdown")
		city_zone_swap("stag") -- STAG shows up in DT

		if game_choice_get_state( MISSION_22_CHOICE ) == M22_CHOICE_KILLBANE_KILL then
			city_zone_swap("rubble") -- Player went for Killbane, statue got blowed up
		else
			city_zone_swap("rubble", false) -- Statue saved
		end


		---------- ZOMBIE STUFF -------------

		-- Set Hood ('Arapice Island') to Spawn Zombies from now on as ambient
		spawn_override_change_hood_alternate_spawning("HOOD_ZOMBIE", true)

		-- Swap the Zombie zone
		city_zone_swap("chemcrash")
		city_zone_swap("zombies")

	end
end

function mrm_stronghold_magic(sh_name,sh_state)

	-- Swap stronghold crib zones from original to Saints cribs and back - called from mission scripts
	-- sh_state = true swaps to saints crib, sh_state = false is original gang controlled

	if sh_name == "safeword" then
		-- Swap zones for BDSM Safeword
		city_zone_swap("megab1",sh_state)
		city_zone_swap("megab2",sh_state)
		city_zone_swap("is2",sh_state)
	elseif sh_name == "nuke" then
		-- Swap Zones for Decker nuke plant
		city_zone_swap("nuke1",sh_state)
		city_zone_swap("nuke2",sh_state)
		city_zone_swap("int_sh03",sh_state)
		city_zone_swap("int_sh03c",sh_state)
	elseif sh_name == "3count" then
		-- Swap Zones for 3 Count Casino
		city_zone_swap("3count1",sh_state)
		city_zone_swap("3count2",sh_state)
		city_zone_swap("int3cc",sh_state)
	end
end
